==> apache-ivy-2.0.0-src.tar.gz: apache-ivy-2.0.0/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.ivy.ant;

import java.io.File;

import junit.framework.TestCase;

import org.apache.ivy.Ivy;
import org.apache.ivy.core.report.ResolveReport;
import org.apache.ivy.util.FileUtil;

public class AntBuildTriggerTest extends TestCase {
    public void test() throws Exception {
        assertFalse(new File("test/triggers/ant-build/A/A.jar").exists());

        Ivy ivy = new Ivy();
        ivy.configure(new File("test/triggers/ant-build/ivysettings.xml"));

        ResolveReport r = ivy.resolve(new File("test/triggers/ant-build/B/ivy.xml"));
        assertFalse(r.hasError());

        // should have triggered an A publish
        assertTrue(new File("test/triggers/ant-build/local/A/A.jar").exists());
    }

    protected void tearDown() throws Exception {
        FileUtil.forceDelete(new File("test/triggers/ant-build/local/A"));
        FileUtil.forceDelete(new File("test/triggers/ant-build/cache"));
    }
}

==> apache-ivy-2.5.3-src.tar.gz: apache-ivy-2.5.3/test/java/org/apache/ivy/ant/AntBuildTriggerTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.ivy.ant;

import java.io.File;

import org.apache.ivy.Ivy;
import org.apache.ivy.core.report.ResolveReport;
import org.apache.ivy.util.FileUtil;

import org.junit.After;
import org.junit.Test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class AntBuildTriggerTest {
    @Test
    public void test() throws Exception {
        assertFalse(new File("test/triggers/ant-build/A/A.jar").exists());

        Ivy ivy = new Ivy();
        ivy.configure(new File("test/triggers/ant-build/ivysettings.xml"));

        ResolveReport r = ivy.resolve(new File("test/triggers/ant-build/B/ivy.xml"));
        assertFalse(r.hasError());

        // should have triggered an A publish
        assertTrue(new File("test/triggers/ant-build/local/A/A.jar").exists());
    }

    @After
    public void tearDown() {
        FileUtil.forceDelete(new File("test/triggers/ant-build/local/A"));
        FileUtil.forceDelete(new File("test/triggers/ant-build/cache"));
    }
}
